Author: David Spickett
Date: 2026-08-27T08:37:52Z
New Revision: bc0eeff161fe80812db132b83d7b9335655a92cd

URL: 
https://github.com/llvm/llvm-project/commit/bc0eeff161fe80812db132b83d7b9335655a92cd
DIFF: 
https://github.com/llvm/llvm-project/commit/bc0eeff161fe80812db132b83d7b9335655a92cd.diff

LOG: [lldb][test] Disable TestDAP_attach.py on AArch64 Linux (#219139)

We've had many reports of timeouts in pre and post-commit.

https://github.com/llvm/llvm-project/issues/137660

Added: 
    

Modified: 
    lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py

Removed: 
    


################################################################################
diff  --git a/lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py 
b/lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py
index bd00ea0d39e21..6f7190828b95c 100644
--- a/lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py
+++ b/lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py
@@ -16,9 +16,11 @@
 )
 
 
-# Often fails on Arm Linux, but not specifically because it's Arm, something in
-# process scheduling can cause a massive (minutes) delay during this test.
-@skipIf(oslist=["linux"], archs=["arm$"])
+# Often fails on Arm/AArch64 Linux, but not specifically because of the
+# architecture, something in process scheduling can cause a massive (minutes)
+# delay during this test.
+# https://github.com/llvm/llvm-project/issues/137660
+@skipIf(oslist=["linux"], archs=["arm$", "aarch64"])
 @requireNotWasm("no attach support")
 class TestDAP_attach(DAPTestCaseBase):
     SHARED_BUILD_TESTCASE = False


        
_______________________________________________
lldb-commits mailing list
[email protected]
https://lists.llvm.org/cgi-bin/mailman/listinfo/lldb-commits

Reply via email to